#ifndef GDHCPD_deactivate_button_clicked_H
#   define GDHCPD_deactivate_button_clicked_H

extern struct w *widgets;

void deactivate_button_clicked(struct w *widgets);

#endif
